//
//  ViewController.swift
//  103-uistackview-in-code
//
//  Created by Jake Marsh on 10/13/15.
//  Copyright © 2015 Jake Marsh. All rights reserved.
//

import UIKit

let lightGrayColor = UIColor(rgba: "#EDEDED")
let blueColor = UIColor(rgba: "#4681A0")

class OnDutyCrewHeaderView : UICollectionReusableView {
  let stackView: UIStackView

  override init(frame: CGRect) {
    let imageView = UIImageView(image: UIImage(named: "crew-icon"))

    let titleLabel = UILabel(frame: CGRectZero)

    titleLabel.font = UIFont(name: "SourceSansPro-Semibold", size: 17.0)
    titleLabel.textColor = lightGrayColor
    titleLabel.text = "31 Crew on Duty"
    titleLabel.setContentHuggingPriority(1, forAxis: .Horizontal)

    let editButton = UIButton(type: .Custom)

    editButton.layer.cornerRadius = 4.0
    editButton.backgroundColor = lightGrayColor
    editButton.setTitleColor(blueColor, forState: .Normal)
    editButton.titleLabel?.font = UIFont(name: "SourceSansPro-SemiboldIt", size: 16.0)
    editButton.contentEdgeInsets = UIEdgeInsetsMake(5.0, 12.0, 5.0, 12.0)
    editButton.setTitle("Edit", forState: .Normal)

    stackView = UIStackView(arrangedSubviews: [imageView, titleLabel, editButton])

    stackView.axis = .Horizontal
    stackView.alignment = .Fill
    stackView.spacing = 10.0
    stackView.layoutMarginsRelativeArrangement = true
    stackView.layoutMargins = UIEdgeInsetsMake(7.0, 7.0, 7.0, 7.0)
    stackView.translatesAutoresizingMaskIntoConstraints = false

    super.init(frame: frame)

    addSubview(stackView)

    func addConstraintsWithVFL(VFL: String) {
      addConstraints(
        NSLayoutConstraint.constraintsWithVisualFormat(
          VFL,
          options: NSLayoutFormatOptions(rawValue: 0),
          metrics: nil,
          views: ["stackView" : stackView ]
        )
      )
    }

    addConstraintsWithVFL("|[stackView]|")
    addConstraintsWithVFL("V:|[stackView]|")

    backgroundColor = blueColor
  }

  required init?(coder aDecoder: NSCoder) {
    fatalError("NSCoding not supported")
  }
}

class ViewController: UIViewController {
  override func viewDidLoad() {
    super.viewDidLoad()

    let sectionHeaderView = OnDutyCrewHeaderView(frame: CGRectZero)
    sectionHeaderView.translatesAutoresizingMaskIntoConstraints = false
    view.addSubview(sectionHeaderView)

    view.addConstraints(["|[sectionHeaderView]|", "V:|-50-[sectionHeaderView]"].flatMap { VFL -> [NSLayoutConstraint] in
      return NSLayoutConstraint.constraintsWithVisualFormat(
        VFL,
        options: NSLayoutFormatOptions(rawValue: 0),
        metrics: nil,
        views: ["sectionHeaderView" : sectionHeaderView ]
      )
    })
  }
}

